package com.loafle.bridge.discoveryport.repository;

import com.loafle.bridge.Application;
import com.loafle.bridge.discoveryport.DiscoveryPort;
import com.loafle.bridge.discoveryport.DiscoveryPortRepository;
import com.loafle.bridge.discoveryport.ServiceScanHistory;
import com.loafle.bridge.discoveryport.type.DirectionType;
import com.loafle.bridge.discoveryport.type.PortType;
import org.apache.log4j.Logger;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import static org.junit.Assert.assertEquals;

/**
 * Created by root on 16. 11. 15.
 */

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = Application.class)
public class DiscoveryPortRepositoryTest {



    @Autowired
    private DiscoveryPortRepository repo;

    Logger l = Logger.getLogger(this.getClass());


    @Before
    public void Before() {
        repo.save(new DiscoveryPort(PortType.TCP,(short)1));
        repo.save(new DiscoveryPort(PortType.UDP, (short)2));
        repo.save(new DiscoveryPort(PortType.TCP, (short)3));
        repo.save(new DiscoveryPort(PortType.UDP, (short)4));
        repo.save(new DiscoveryPort(PortType.TCP, (short)5));
    }

    @After
    public void After() {
        repo.deleteAll();
    }

    @Test
    @Transactional
    public void TestInsertPort() {
        DiscoveryPort p = new DiscoveryPort(PortType.TCP, (short)1);

        repo.save(p);
        DiscoveryPort compare = repo.findOne(p.getId());

        assertEquals(p.getId(),compare.getId());

        l.debug("!!!!!!!" + compare.getId());
        l.debug("!!!!!!!" + compare.getPortType());
        l.debug("!!!!!!!" + compare.getPortNumber());
        l.debug("!!!!!!!" + compare.getCreateDate());
        l.debug("!!!!!!!" + compare.getUpdateDate());

    }

    @Test
    @Transactional
    public void TestInsertServiceHistory() {
        List<DiscoveryPort> list = repo.findAll();

        DiscoveryPort p = list.get(0);

        List<ServiceScanHistory> h = new ArrayList<ServiceScanHistory>();
        byte [] a = {10,20,30,40,50};
        h.add(new ServiceScanHistory(p,"testservice1", DirectionType.Send,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice2", DirectionType.Recv,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice3", DirectionType.Send,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice4", DirectionType.Recv,a, new Date()));
        h.add(new ServiceScanHistory(p,"testservice5", DirectionType.Send,a, new Date()));

        p.setHistories(h);
        repo.save(p);

        repo.flush();
        DiscoveryPort find = repo.findOne(p.getId());

        List<ServiceScanHistory> l1 = p.getHistories();
        List<ServiceScanHistory> l2 = find.getHistories();

        assertEquals(l1.size(), l2.size());

        for (int i =0 ; i < l2.size() ; ++i) {
            ServiceScanHistory s = l2.get(i);
            l.debug(s.getDirection());

        }
    }
}